@@ -3,7 +3,7 @@ from lovely.pyrest.service import Service
 svc = Service(name='svc', path='/svc')
 
 
-@svc.get(accept="text/plain", accept_catch_all=False)
+@svc.get(accept="text/plain", accept_catch_all=False, renderer='string')
 def get(request):
     return "'title': 'Hello World!'"
 
